
//----------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------
//
//  "uirCommandListStatus.c"
//
//  Implementation file for UI build functions
//
//  Date: 11-07-2004
//
//----------------------------------------------------------------------------------------------------
//----------------------------------------------------------------------------------------------------

//----------------------------------------------------------------------------------------------------
//  Include header files
//----------------------------------------------------------------------------------------------------

#include "uirCommandListStatus.h"
#include <Utility.h> // definition of NULL
#include "toolbox.h" // definition of errChk macro

extern int CVIFUNC_C GetUserBitmapFromText (char *imageText, int version, int *bitmapId); // needed if there are bitmaps
extern int CVIFUNC_C NewActiveXCtrlFromPersistence (int panel, const char *ctrlLabel,
                                                    int top, int left, char *defaultIID,
                                                    int binaryFormat, char *persistenceText,
                                                    HRESULT *activeXError); // needed if there are ActiveX controls

//----------------------------------------------------------------------------------------------------
//  Prototype UI build functions.
//----------------------------------------------------------------------------------------------------

int buildCmdListStatusPanel (int hParentPanel);
int buildCmdListStatusMenu (int hParentPanel);

//-------------------------------------------------------------------------------------------------
// Prototype callbacks for Panel: CLISTP
// ------------------------------------------------------------------------------------------------

// Control: CLISTP_LIST_FILE
int CVICALLBACK commandButtons (int panelHandle, int control, int event, void *callbackData, int eventData1, int eventData2);

// Control: CLISTP_SEND_LIST
int CVICALLBACK commandButtons (int panelHandle, int control, int event, void *callbackData, int eventData1, int eventData2);

// Control: CLISTP_NUM_OF_LIST_REP
int CVICALLBACK commandButtons (int panelHandle, int control, int event, void *callbackData, int eventData1, int eventData2);

// Control: CLISTP_EDIT_CLIST
int CVICALLBACK commandButtons (int panelHandle, int control, int event, void *callbackData, int eventData1, int eventData2);

// Control: CLISTP_RESET_CMDREP
int CVICALLBACK commandButtons (int panelHandle, int control, int event, void *callbackData, int eventData1, int eventData2);

// Control: CLISTP_RESET_REP_LIST_NUM
int CVICALLBACK commandButtons (int panelHandle, int control, int event, void *callbackData, int eventData1, int eventData2);

// Control: CLISTP_RESUME_CTRL_THREAD
int CVICALLBACK commandButtons (int panelHandle, int control, int event, void *callbackData, int eventData1, int eventData2);

// Control: CLISTP_RESET_CTRL_THREAD
int CVICALLBACK commandButtons (int panelHandle, int control, int event, void *callbackData, int eventData1, int eventData2);

//-------------------------------------------------------------------------------------------------
// Prototype callbacks for Menubar: CSTAT_MENU
// ------------------------------------------------------------------------------------------------

// Menu: CLEAR_STATUS_WINDOW
void CVICALLBACK commandStatusMenu (int menubarHandle, int menuItemID, void *callbackPtr, int panelHandle);

// Menu: OPEN_STATUS_FILE
void CVICALLBACK commandStatusMenu (int menubarHandle, int menuItemID, void *callbackPtr, int panelHandle);

// Menu: CMD_LIST_EDITOR
void CVICALLBACK commandStatusMenu (int menubarHandle, int menuItemID, void *callbackPtr, int panelHandle);

// Menu: CLOSE_WINDOW
void CVICALLBACK commandStatusMenu (int menubarHandle, int menuItemID, void *callbackPtr, int panelHandle);


//-------------------------------------------------------------------------------------------------
// Declare identifiers for Panel:  CLISTP
// ------------------------------------------------------------------------------------------------

int CLISTP_COMMAND_RING                      ;     // control identifier
int CLISTP_HOST_INDEX                        ;     // control identifier
int CLISTP_LIST_FILE                         ;     // control identifier
int CLISTP_SEND_LIST                         ;     // control identifier
int CLISTP_NUM_COMMANDS                      ;     // control identifier
int CLISTP_COMMAND_INDEX                     ;     // control identifier
int CLISTP_CMDREP                            ;     // control identifier
int CLISTP_CMDREP_COUNT                      ;     // control identifier
int CLISTP_LIST_REP_COUNTER                  ;     // control identifier
int CLISTP_NUM_OF_LIST_REP                   ;     // control identifier
int CLISTP_EDIT_CLIST                        ;     // control identifier
int CLISTP_RESET_CMDREP                      ;     // control identifier
int CLISTP_RESET_REP_LIST_NUM                ;     // control identifier
int CLISTP_STOPPED                           ;     // control identifier
int CLISTP_BUSY                              ;     // control identifier
int CLISTP_STATUS_BOX                        ;     // control identifier
int CLISTP_IF_ERROR                          ;     // control identifier
int CLISTP_RESUME_CTRL_THREAD                ;     // control identifier
int CLISTP_RESET_CTRL_THREAD                 ;     // control identifier
int CLISTP_DECORATION_12                     ;     // control identifier
int CLISTP_DECORATION                        ;     // control identifier
int CLISTP_TEXTMSG_3                         ;     // control identifier

//-------------------------------------------------------------------------------------------------
// Declare identifiers for Menubar:  CSTAT_MENU
// ------------------------------------------------------------------------------------------------

int CSTAT_MENU_CLEAR_STATUS_WINDOW           ;     // menu identifier
int CSTAT_MENU_OPEN_STATUS_FILE              ;     // menu identifier
int CSTAT_MENU_CMD_LIST_EDITOR               ;     // menu identifier
int CSTAT_MENU_CLOSE_WINDOW                  ;     // menu identifier

//----------------------------------------------------------------------------------------------------
// buildCmdListStatusPanel ():  Build UI object CLISTP; return handle or standard UI error code.
//----------------------------------------------------------------------------------------------------
int buildCmdListStatusPanel (int hParentPanel)
{
    int hPanel;
    int error = 0;
    int hMenubar;
    int screenHeight;
    int screenWidth;
    int resAdjustment;
    int monitorId;
    int bitmapId = 0; // needed if there are bitmaps 
    char *dataPtr = NULL; 
    float SFv;
    float SFh;

    // Create the panel
    errChk(hPanel = NewPanel (hParentPanel, "COMMAND LIST STATUS", 85, 424, 510, 326));

    // Set the panel's attributes
    errChk(SetPanelAttribute (hPanel, ATTR_CONSTANT_NAME, "CLISTP"));
    errChk(SetPanelAttribute (hPanel, ATTR_CALLBACK_FUNCTION_POINTER, 0));
//  errChk(SetPanelAttribute (hPanel, ATTR_DIMMED, 0));
    if (hParentPanel)
        errChk(SetPanelAttribute (hPanel, ATTR_FRAME_COLOR, 0X6098B7));
//  errChk(SetPanelAttribute (hPanel, ATTR_SCROLL_BARS, VAL_NO_SCROLL_BARS));
    errChk(SetPanelAttribute (hPanel, ATTR_SCROLL_BAR_COLOR, VAL_LT_GRAY));
//  errChk(SetPanelAttribute (hPanel, ATTR_HSCROLL_OFFSET, 0));
    errChk(SetPanelAttribute (hPanel, ATTR_BACKCOLOR, 0X93B9CE));
//  errChk(SetPanelAttribute (hPanel, ATTR_TITLEBAR_VISIBLE, 1));
    if (hParentPanel)
        errChk(SetPanelAttribute (hPanel, ATTR_TITLEBAR_THICKNESS, 19));
    if (hParentPanel)
        errChk(SetPanelAttribute (hPanel, ATTR_TITLE_COLOR, VAL_OFFWHITE));
    if (hParentPanel)
        errChk(SetPanelAttribute (hPanel, ATTR_TITLE_BACKCOLOR, 0X6098B7));
//  if (hParentPanel)
    //  errChk(SetPanelAttribute (hPanel, ATTR_FRAME_STYLE, VAL_RAISED_OUTLINED_FRAME));
    if (hParentPanel)
        errChk(SetPanelAttribute (hPanel, ATTR_FRAME_THICKNESS, 10));
    errChk(SetPanelAttribute (hPanel, ATTR_SIZABLE, 0));
//  errChk(SetPanelAttribute (hPanel, ATTR_MOVABLE, 1));
    if (hParentPanel)
        errChk(SetPanelAttribute (hPanel, ATTR_TITLE_FONT, "VAL_DIALOG_FONT"));
//  if (hParentPanel)
    //  errChk(SetPanelAttribute (hPanel, ATTR_TITLE_ITALIC, 0));
//  if (hParentPanel)
    //  errChk(SetPanelAttribute (hPanel, ATTR_TITLE_UNDERLINE, 0));
//  if (hParentPanel)
    //  errChk(SetPanelAttribute (hPanel, ATTR_TITLE_STRIKEOUT, 0));
    if (hParentPanel)
        errChk(SetPanelAttribute (hPanel, ATTR_TITLE_POINT_SIZE, 13));
    if (hParentPanel)
        errChk(SetPanelAttribute (hPanel, ATTR_TITLE_BOLD, 1));
//  if (hParentPanel)
    //  errChk(SetPanelAttribute (hPanel, ATTR_PARENT_SHARES_SHORTCUT_KEYS, 1));
//  if (hParentPanel)
    //  errChk(SetPanelAttribute (hPanel, ATTR_ACTIVATE_WHEN_CLICKED_ON, 1));
    errChk(SetPanelAttribute (hPanel, ATTR_CAN_MINIMIZE, 0));
    errChk(SetPanelAttribute (hPanel, ATTR_CAN_MAXIMIZE, 0));
    errChk(SetPanelAttribute (hPanel, ATTR_MIN_HEIGHT_FOR_SCALING, 0));
    errChk(SetPanelAttribute (hPanel, ATTR_MIN_WIDTH_FOR_SCALING, 0));
//  if (!hParentPanel)
    //  errChk(SetPanelAttribute (hPanel, ATTR_FLOATING, VAL_FLOAT_NEVER));
//  errChk(SetPanelAttribute (hPanel, ATTR_CLOSE_ITEM_VISIBLE, 1));
//  errChk(SetPanelAttribute (hPanel, ATTR_SYSTEM_MENU_VISIBLE, 1));
//  if (hParentPanel)
    //  errChk(SetPanelAttribute (hPanel, ATTR_TITLE_SIZE_TO_FONT, 1));
//  errChk(SetPanelAttribute (hPanel, ATTR_HAS_TASKBAR_BUTTON, 0));
//  errChk(SetPanelAttribute (hPanel, ATTR_VSCROLL_OFFSET, 0));

    // Build control: CLISTP_COMMAND_RING
    errChk(CLISTP_COMMAND_RING = NewCtrl (hPanel, CTRL_RING, "Command", 69, 79));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_CONSTANT_NAME, "COMMAND_RING"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_VISIBLE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_SHORTCUT_KEY, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_DATA_TYPE, VAL_UNSIGNED_INTEGER));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_FRAME_COLOR, 0XB0B0B0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_DISABLE_CHECK_MARK, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_CTRL_MODE, VAL_INDICATOR));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_COLOR, 0X202020));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_BOLD, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_WIDTH, 50));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_BGCOLOR, VAL_TRANSPARENT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_RAISED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_JUSTIFY, VAL_CENTER_JUSTIFIED));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_TEXT_COLOR, 0X000066));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_TEXT_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_TEXT_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_TEXT_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_TEXT_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_TEXT_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_TEXT_BOLD, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_TEXT_BGCOLOR, VAL_OFFWHITE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_WIDTH, 190));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_TOP, 54));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_LEFT, 138));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_LABEL_SIZE_TO_TEXT, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_TEXT_JUSTIFY, VAL_CENTER_JUSTIFIED));

    // Build control: CLISTP_HOST_INDEX
    errChk(CLISTP_HOST_INDEX = NewCtrl (hPanel, CTRL_NUMERIC, "HostIndex", 33, 14));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_CONSTANT_NAME, "HOST_INDEX"));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_VISIBLE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_SHORTCUT_KEY, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_DATA_TYPE, VAL_UNSIGNED_CHAR));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_FRAME_COLOR, VAL_LT_GRAY));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_CTRL_MODE, VAL_INDICATOR));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_COLOR, VAL_WHITE));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_BOLD, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_WIDTH, 51));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_BGCOLOR, VAL_TRANSPARENT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_RAISED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_JUSTIFY, VAL_CENTER_JUSTIFIED));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_TEXT_COLOR, VAL_BLACK));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_TEXT_FONT, VAL_DIALOG_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_TEXT_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_TEXT_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_TEXT_STRIKEOUT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_TEXT_POINT_SIZE, 13));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_TEXT_BOLD, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_TEXT_BGCOLOR, VAL_WHITE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_MAX_VALUE, 21));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_MIN_VALUE, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_INCR_VALUE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_FORMAT, VAL_DECIMAL_FORMAT));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_PRECISION, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_CHECK_RANGE, VAL_NOTIFY));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_PADDING, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_SHOW_RADIX, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_HOST_INDEX));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_SHOW_INCDEC_ARROWS, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_NO_EDIT_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_WIDTH, 30));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_TOP, 19));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_LEFT, 5));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_LABEL_SIZE_TO_TEXT, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_TEXT_JUSTIFY, VAL_CENTER_JUSTIFIED));

    // Build control: CLISTP_LIST_FILE
    errChk(CLISTP_LIST_FILE = NewCtrl (hPanel, CTRL_STRING, "", 163, 43));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_CONSTANT_NAME, "LIST_FILE"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_CALLBACK_FUNCTION_POINTER, commandButtons));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_SHORTCUT_KEY, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_FRAME_COLOR, 0XCC9966));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_CTRL_MODE, VAL_INDICATOR));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_BOLD, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_WIDTH, 9));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_BGCOLOR, 0XB0B0B0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_RAISED, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_JUSTIFY, VAL_LEFT_JUSTIFIED));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_TEXT_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_TEXT_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_TEXT_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_TEXT_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_TEXT_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_TEXT_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_TEXT_BOLD, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_TEXT_BGCOLOR, VAL_WHITE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_DFLT_VALUE, ""));
    errChk(DefaultCtrl (hPanel, CLISTP_LIST_FILE));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_MAX_ENTRY_LENGTH, -1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_NO_EDIT_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_WIDTH, 273));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_TOP, 143));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_LEFT, 250));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_LABEL_SIZE_TO_TEXT, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_TEXT_JUSTIFY, VAL_RIGHT_JUSTIFIED));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_HSCROLL_OFFSET, 0));

    // Build control: CLISTP_SEND_LIST
    errChk(CLISTP_SEND_LIST = NewCtrl (hPanel, CTRL_SQUARE_COMMAND_BUTTON, "SEND COMMAND LIST", 187, 127));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_CONSTANT_NAME, "SEND_LIST"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_CALLBACK_FUNCTION_POINTER, commandButtons));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_SHORTCUT_KEY, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_CTRL_MODE, VAL_HOT));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_LABEL_COLOR, 0X000066));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_LABEL_FONT, VAL_DIALOG_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_LABEL_POINT_SIZE, 11));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_LABEL_BOLD, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_SEND_LIST));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_CMD_BUTTON_COLOR, 0XCC9966));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_AUTO_SIZING, VAL_NEVER_AUTO_SIZE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_HEIGHT, 23));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_WIDTH, 189));

    // Build control: CLISTP_NUM_COMMANDS
    errChk(CLISTP_NUM_COMMANDS = NewCtrl (hPanel, CTRL_NUMERIC, "nCmds", 69, 10));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_CONSTANT_NAME, "NUM_COMMANDS"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_VISIBLE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_SHORTCUT_KEY, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_DATA_TYPE, VAL_UNSIGNED_INTEGER));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_FRAME_COLOR, 0XB0B0B0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_CTRL_MODE, VAL_INDICATOR));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_BOLD, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_WIDTH, 35));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_BGCOLOR, VAL_TRANSPARENT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_RAISED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_JUSTIFY, VAL_CENTER_JUSTIFIED));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_TEXT_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_TEXT_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_TEXT_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_TEXT_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_TEXT_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_TEXT_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_TEXT_BOLD, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_TEXT_BGCOLOR, VAL_OFFWHITE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_MAX_VALUE, -1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_MIN_VALUE, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_INCR_VALUE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_FORMAT, VAL_DECIMAL_FORMAT));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_PRECISION, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_CHECK_RANGE, VAL_NOTIFY));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_PADDING, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_SHOW_RADIX, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_NUM_COMMANDS));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_SHOW_INCDEC_ARROWS, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_NO_EDIT_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_WIDTH, 30));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_TOP, 54));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_LEFT, 7));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_LABEL_SIZE_TO_TEXT, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_TEXT_JUSTIFY, VAL_CENTER_JUSTIFIED));

    // Build control: CLISTP_COMMAND_INDEX
    errChk(CLISTP_COMMAND_INDEX = NewCtrl (hPanel, CTRL_NUMERIC, "Index", 69, 43));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_CONSTANT_NAME, "COMMAND_INDEX"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_VISIBLE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_SHORTCUT_KEY, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_DATA_TYPE, VAL_UNSIGNED_INTEGER));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_FRAME_COLOR, 0X006699));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_CTRL_MODE, VAL_INDICATOR));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_BOLD, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_WIDTH, 29));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_BGCOLOR, VAL_TRANSPARENT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_RAISED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_JUSTIFY, VAL_CENTER_JUSTIFIED));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_TEXT_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_TEXT_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_TEXT_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_TEXT_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_TEXT_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_TEXT_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_TEXT_BOLD, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_TEXT_BGCOLOR, VAL_OFFWHITE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_MAX_VALUE, -1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_MIN_VALUE, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_INCR_VALUE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_FORMAT, VAL_DECIMAL_FORMAT));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_PRECISION, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_CHECK_RANGE, VAL_NOTIFY));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_PADDING, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_SHOW_RADIX, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_COMMAND_INDEX));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_SHOW_INCDEC_ARROWS, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_NO_EDIT_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_WIDTH, 30));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_TOP, 54));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_LEFT, 43));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_LABEL_SIZE_TO_TEXT, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_TEXT_JUSTIFY, VAL_CENTER_JUSTIFIED));

    // Build control: CLISTP_CMDREP
    errChk(CLISTP_CMDREP = NewCtrl (hPanel, CTRL_NUMERIC, "Rep", 95, 105));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_CONSTANT_NAME, "CMDREP"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_VISIBLE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_SHORTCUT_KEY, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_DATA_TYPE, VAL_UNSIGNED_INTEGER));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_FRAME_COLOR, VAL_LT_GRAY));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_CTRL_MODE, VAL_INDICATOR));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_BOLD, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_WIDTH, 48));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_BGCOLOR, VAL_TRANSPARENT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_RAISED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_JUSTIFY, VAL_CENTER_JUSTIFIED));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_TEXT_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_TEXT_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_TEXT_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_TEXT_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_TEXT_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_TEXT_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_TEXT_BOLD, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_TEXT_BGCOLOR, VAL_OFFWHITE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_MAX_VALUE, -1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_MIN_VALUE, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_INCR_VALUE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_FORMAT, VAL_DECIMAL_FORMAT));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_PRECISION, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_CHECK_RANGE, VAL_NOTIFY));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_PADDING, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_SHOW_RADIX, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_CMDREP));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_SHOW_INCDEC_ARROWS, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_NO_EDIT_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_WIDTH, 45));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_TOP, 96));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_LEFT, 69));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_LABEL_SIZE_TO_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_TEXT_JUSTIFY, VAL_CENTER_JUSTIFIED));

    // Build control: CLISTP_CMDREP_COUNT
    errChk(CLISTP_CMDREP_COUNT = NewCtrl (hPanel, CTRL_NUMERIC, "Cnt", 94, 177));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_CONSTANT_NAME, "CMDREP_COUNT"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_VISIBLE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_SHORTCUT_KEY, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_DATA_TYPE, VAL_UNSIGNED_INTEGER));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_FRAME_COLOR, 0X006699));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_CTRL_MODE, VAL_INDICATOR));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_BOLD, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_WIDTH, 48));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_BGCOLOR, VAL_TRANSPARENT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_RAISED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_JUSTIFY, VAL_CENTER_JUSTIFIED));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_TEXT_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_TEXT_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_TEXT_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_TEXT_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_TEXT_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_TEXT_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_TEXT_BOLD, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_TEXT_BGCOLOR, VAL_OFFWHITE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_MAX_VALUE, -1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_MIN_VALUE, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_INCR_VALUE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_FORMAT, VAL_DECIMAL_FORMAT));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_PRECISION, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_CHECK_RANGE, VAL_NOTIFY));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_PADDING, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_SHOW_RADIX, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_CMDREP_COUNT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_SHOW_INCDEC_ARROWS, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_NO_EDIT_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_WIDTH, 45));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_TOP, 96));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_LEFT, 142));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_LABEL_SIZE_TO_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_TEXT_JUSTIFY, VAL_CENTER_JUSTIFIED));

    // Build control: CLISTP_LIST_REP_COUNTER
    errChk(CLISTP_LIST_REP_COUNTER = NewCtrl (hPanel, CTRL_NUMERIC, "Counter", 136, 157));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_CONSTANT_NAME, "LIST_REP_COUNTER"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_VISIBLE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_SHORTCUT_KEY, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_DATA_TYPE, VAL_UNSIGNED_INTEGER));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_FRAME_COLOR, 0X006699));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_CTRL_MODE, VAL_INDICATOR));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_COLOR, VAL_BLACK));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_FONT, VAL_DIALOG_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_POINT_SIZE, 11));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_BOLD, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_WIDTH, 48));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_BGCOLOR, VAL_TRANSPARENT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_RAISED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_JUSTIFY, VAL_CENTER_JUSTIFIED));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_TEXT_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_TEXT_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_TEXT_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_TEXT_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_TEXT_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_TEXT_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_TEXT_BOLD, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_TEXT_BGCOLOR, VAL_WHITE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_MAX_VALUE, -1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_MIN_VALUE, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_INCR_VALUE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_FORMAT, VAL_DECIMAL_FORMAT));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_PRECISION, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_CHECK_RANGE, VAL_NOTIFY));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_PADDING, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_SHOW_RADIX, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_LIST_REP_COUNTER));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_SHOW_INCDEC_ARROWS, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_NO_EDIT_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_WIDTH, 65));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_TOP, 121));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_LEFT, 166));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_LABEL_SIZE_TO_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_TEXT_JUSTIFY, VAL_CENTER_JUSTIFIED));

    // Build control: CLISTP_NUM_OF_LIST_REP
    errChk(CLISTP_NUM_OF_LIST_REP = NewCtrl (hPanel, CTRL_NUMERIC, "ListRep", 136, 76));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_CONSTANT_NAME, "NUM_OF_LIST_REP"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_CALLBACK_FUNCTION_POINTER, commandButtons));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_SHORTCUT_KEY, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_DATA_TYPE, VAL_UNSIGNED_INTEGER));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_FRAME_COLOR, 0XCC9966));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_CTRL_MODE, VAL_NORMAL));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_COLOR, VAL_BLACK));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_FONT, VAL_DIALOG_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_POINT_SIZE, 11));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_BOLD, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_WIDTH, 47));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_BGCOLOR, VAL_TRANSPARENT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_RAISED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_JUSTIFY, VAL_CENTER_JUSTIFIED));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_TEXT_COLOR, VAL_BLACK));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_TEXT_FONT, VAL_DIALOG_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_TEXT_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_TEXT_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_TEXT_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_TEXT_POINT_SIZE, 11));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_TEXT_BOLD, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_TEXT_BGCOLOR, VAL_WHITE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_MAX_VALUE, -1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_MIN_VALUE, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_INCR_VALUE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_FORMAT, VAL_DECIMAL_FORMAT));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_PRECISION, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_CHECK_RANGE, VAL_NOTIFY));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_PADDING, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_SHOW_RADIX, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_NUM_OF_LIST_REP));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_SHOW_INCDEC_ARROWS, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_NO_EDIT_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_WIDTH, 74));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_TOP, 121));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_LEFT, 94));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_LABEL_SIZE_TO_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_TEXT_JUSTIFY, VAL_CENTER_JUSTIFIED));

    // Build control: CLISTP_EDIT_CLIST
    errChk(CLISTP_EDIT_CLIST = NewCtrl (hPanel, CTRL_OBLONG_COMMAND_BUTTON, "EDIT", 187, 71));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_CONSTANT_NAME, "EDIT_CLIST"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_CALLBACK_FUNCTION_POINTER, commandButtons));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_SHORTCUT_KEY, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_CTRL_MODE, VAL_HOT));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_LABEL_COLOR, 0X000066));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_LABEL_FONT, VAL_APP_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_LABEL_STRIKEOUT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_LABEL_POINT_SIZE, 9));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_LABEL_BOLD, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_EDIT_CLIST));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_CMD_BUTTON_COLOR, 0XCC9966));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_AUTO_SIZING, VAL_NEVER_AUTO_SIZE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_HEIGHT, 23));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_WIDTH, 36));

    // Build control: CLISTP_RESET_CMDREP
    errChk(CLISTP_RESET_CMDREP = NewCtrl (hPanel, CTRL_SQUARE_COMMAND_BUTTON, "Stop", 95, 44));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_CONSTANT_NAME, "RESET_CMDREP"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_CALLBACK_FUNCTION_POINTER, commandButtons));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_SHORTCUT_KEY, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_CTRL_MODE, VAL_HOT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_LABEL_COLOR, VAL_BLACK));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_LABEL_FONT, VAL_APP_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_LABEL_STRIKEOUT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_LABEL_POINT_SIZE, 9));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_LABEL_BOLD, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_RESET_CMDREP));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_CMD_BUTTON_COLOR, 0XCC9966));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_AUTO_SIZING, VAL_NEVER_AUTO_SIZE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_HEIGHT, 19));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_WIDTH, 28));

    // Build control: CLISTP_RESET_REP_LIST_NUM
    errChk(CLISTP_RESET_REP_LIST_NUM = NewCtrl (hPanel, CTRL_SQUARE_COMMAND_BUTTON, "Stop", 136, 44));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_CONSTANT_NAME, "RESET_REP_LIST_NUM"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_CALLBACK_FUNCTION_POINTER, commandButtons));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_SHORTCUT_KEY, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_CTRL_MODE, VAL_HOT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_LABEL_COLOR, VAL_BLACK));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_LABEL_FONT, VAL_APP_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_LABEL_STRIKEOUT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_LABEL_POINT_SIZE, 9));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_LABEL_BOLD, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_RESET_REP_LIST_NUM));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_CMD_BUTTON_COLOR, 0XCC9966));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_AUTO_SIZING, VAL_NEVER_AUTO_SIZE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_HEIGHT, 19));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_WIDTH, 28));

    // Build control: CLISTP_STOPPED
    errChk(CLISTP_STOPPED = NewCtrl (hPanel, CTRL_SQUARE_LED, "Stopped", 26, 166));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_CONSTANT_NAME, "STOPPED"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_VISIBLE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_SHORTCUT_KEY, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_CTRL_MODE, VAL_INDICATOR));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_COLOR, 0XFFCC00));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_FONT, VAL_DIALOG_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_POINT_SIZE, 11));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_BOLD, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_WIDTH, 51));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_BGCOLOR, VAL_TRANSPARENT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_RAISED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_JUSTIFY, VAL_CENTER_JUSTIFIED));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_STOPPED));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_ON_COLOR, VAL_RED));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_OFF_COLOR, VAL_LT_GRAY));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_HEIGHT, 22));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_WIDTH, 57));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_TOP, 28));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_LEFT, 169));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_LABEL_SIZE_TO_TEXT, 1));

    // Build control: CLISTP_BUSY
    errChk(CLISTP_BUSY = NewCtrl (hPanel, CTRL_SQUARE_LED, "Busy", 26, 115));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_CONSTANT_NAME, "BUSY"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_VISIBLE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_SHORTCUT_KEY, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_CTRL_MODE, VAL_INDICATOR));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_BOLD, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_WIDTH, 26));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_BGCOLOR, VAL_TRANSPARENT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_RAISED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_JUSTIFY, VAL_CENTER_JUSTIFIED));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_BUSY));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_ON_COLOR, VAL_YELLOW));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_OFF_COLOR, VAL_LT_GRAY));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_HEIGHT, 22));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_WIDTH, 48));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_TOP, 28));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_LEFT, 126));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_LABEL_SIZE_TO_TEXT, 1));

    // Build control: CLISTP_STATUS_BOX
    errChk(CLISTP_STATUS_BOX = NewCtrl (hPanel, CTRL_TEXT_BOX, "", 216, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_CONSTANT_NAME, "STATUS_BOX"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_VISIBLE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_SHORTCUT_KEY, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_FRAME_COLOR, VAL_LT_GRAY));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_SCROLL_BARS, VAL_BOTH_SCROLL_BARS));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_SCROLL_BAR_COLOR, VAL_LT_GRAY));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_SCROLL_BAR_SIZE, VAL_LARGE_SCROLL_BARS));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_CTRL_MODE, VAL_INDICATOR));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_COLOR, VAL_BLACK));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_FONT, VAL_DIALOG_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_POINT_SIZE, 11));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_BOLD, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_WIDTH, 11));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_BGCOLOR, VAL_TRANSPARENT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_RAISED, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_JUSTIFY, VAL_LEFT_JUSTIFIED));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_TEXT_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_TEXT_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_TEXT_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_TEXT_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_TEXT_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_TEXT_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_TEXT_BOLD, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_TEXT_BGCOLOR, VAL_WHITE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_DFLT_VALUE, ""));
    errChk(DefaultCtrl (hPanel, CLISTP_STATUS_BOX));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_MAX_ENTRY_LENGTH, -1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_WRAP_MODE, VAL_LINE_WRAP));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_ENTER_IS_NEWLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_FIRST_VISIBLE_LINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_EXTRA_LINES, -1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_NO_EDIT_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_HEIGHT, 295));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_WIDTH, 325));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_TOP, 201));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_LEFT, 134));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_LABEL_SIZE_TO_TEXT, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_TEXT_JUSTIFY, VAL_LEFT_JUSTIFIED));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_HSCROLL_OFFSET, 0));

    // Build control: CLISTP_IF_ERROR
    errChk(CLISTP_IF_ERROR = NewCtrl (hPanel, CTRL_RECESSED_MENU_RING, "If Error", 136, 240));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_CONSTANT_NAME, "IF_ERROR"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_VISIBLE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_SHORTCUT_KEY, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_DATA_TYPE, VAL_INTEGER));
    errChk(InsertListItem (hPanel, CLISTP_IF_ERROR, 0, "DEFAULT", 0));
    errChk(InsertListItem (hPanel, CLISTP_IF_ERROR, 1, "STOP", 1));
    errChk(InsertListItem (hPanel, CLISTP_IF_ERROR, 2, "CONTINUE", 2));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_FRAME_COLOR, 0XCC9966));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_DISABLE_CHECK_MARK, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_CTRL_MODE, VAL_NORMAL));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_COLOR, VAL_BLACK));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_FONT, VAL_DIALOG_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_POINT_SIZE, 11));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_BOLD, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_WIDTH, 43));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_BGCOLOR, VAL_TRANSPARENT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_RAISED, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_JUSTIFY, VAL_LEFT_JUSTIFIED));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_TEXT_COLOR, VAL_BLACK));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_TEXT_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_TEXT_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_TEXT_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_TEXT_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_TEXT_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_TEXT_BOLD, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_TEXT_BGCOLOR, VAL_WHITE));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_DFLT_INDEX, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_IF_ERROR));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_MENU_ARROW_COLOR, VAL_BLACK));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_WIDTH, 75));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_TOP, 122));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_LEFT, 254));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_LABEL_SIZE_TO_TEXT, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_TEXT_JUSTIFY, VAL_CENTER_JUSTIFIED));

    // Build control: CLISTP_RESUME_CTRL_THREAD
    errChk(CLISTP_RESUME_CTRL_THREAD = NewCtrl (hPanel, CTRL_SQUARE_COMMAND_BUTTON, "Resume", 27, 276));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_CONSTANT_NAME, "RESUME_CTRL_THREAD"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_CALLBACK_FUNCTION_POINTER, commandButtons));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_SHORTCUT_KEY, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_CTRL_MODE, VAL_HOT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_LABEL_COLOR, VAL_BLACK));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_LABEL_FONT, VAL_APP_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_LABEL_STRIKEOUT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_LABEL_POINT_SIZE, 9));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_LABEL_BOLD, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_RESUME_CTRL_THREAD));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_CMD_BUTTON_COLOR, 0XCC9966));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_AUTO_SIZING, VAL_NEVER_AUTO_SIZE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_HEIGHT, 20));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_WIDTH, 42));

    // Build control: CLISTP_RESET_CTRL_THREAD
    errChk(CLISTP_RESET_CTRL_THREAD = NewCtrl (hPanel, CTRL_SQUARE_COMMAND_BUTTON, "Reset", 27, 228));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_CONSTANT_NAME, "RESET_CTRL_THREAD"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_CALLBACK_FUNCTION_POINTER, commandButtons));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_SHORTCUT_KEY, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_CTRL_MODE, VAL_HOT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_LABEL_COLOR, VAL_BLACK));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_LABEL_FONT, VAL_APP_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_LABEL_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_LABEL_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_LABEL_STRIKEOUT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_LABEL_POINT_SIZE, 9));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_LABEL_BOLD, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_LABEL_VISIBLE, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_DFLT_VALUE, 0));
    errChk(DefaultCtrl (hPanel, CLISTP_RESET_CTRL_THREAD));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_CMD_BUTTON_COLOR, 0XCC9966));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_AUTO_SIZING, VAL_NEVER_AUTO_SIZE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_HEIGHT, 20));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_WIDTH, 42));

    // Build control: CLISTP_DECORATION_12
    errChk(CLISTP_DECORATION_12 = NewCtrl (hPanel, CTRL_FLAT_BOX, "", 301, 79));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION_12, ATTR_CONSTANT_NAME, "DECORATION_12"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION_12, ATTR_VISIBLE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION_12, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION_12, ATTR_SHORTCUT_KEY, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION_12, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION_12, ATTR_FRAME_COLOR, 0XC4D0D2));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION_12, ATTR_CTRL_MODE, VAL_INDICATOR));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION_12, ATTR_HEIGHT, 72));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION_12, ATTR_WIDTH, 198));

    // Build control: CLISTP_DECORATION
    errChk(CLISTP_DECORATION = NewCtrl (hPanel, CTRL_RECESSED_BOX, "", 53, 4));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION, ATTR_CONSTANT_NAME, "DECORATION"));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION, ATTR_VISIBLE, 1));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION, ATTR_SHORTCUT_KEY, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION, ATTR_FRAME_COLOR, 0X93B9CE));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION, ATTR_CTRL_MODE, VAL_INDICATOR));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION, ATTR_HEIGHT, 67));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION, ATTR_WIDTH, 317));

    // Build control: CLISTP_TEXTMSG_3
    errChk(CLISTP_TEXTMSG_3 = NewCtrl (hPanel, CTRL_TEXT_MSG, "", 71, 96));
    errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_CONSTANT_NAME, "TEXTMSG_3"));
    errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_VISIBLE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_CALLBACK_FUNCTION_POINTER, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_SHORTCUT_KEY, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_DIMMED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_CTRL_MODE, VAL_INDICATOR));
    errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_TEXT_COLOR, VAL_RED));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_TEXT_FONT, VAL_DIALOG_META_FONT));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_TEXT_ITALIC, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_TEXT_UNDERLINE, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_TEXT_STRIKEOUT, 0));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_TEXT_POINT_SIZE, 11));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_TEXT_BOLD, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_TEXT_BGCOLOR, VAL_TRANSPARENT));
    errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_DFLT_VALUE, "RING FILLED IN fillUirControls.c"));
    errChk(DefaultCtrl (hPanel, CLISTP_TEXTMSG_3));
//  errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_TEXT_RAISED, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_HEIGHT, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_WIDTH, 155));
    errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_SIZE_TO_TEXT, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_TEXT_JUSTIFY, VAL_LEFT_JUSTIFIED));

    // Set up ZPLANE order if necessary
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_ZPLANE_POSITION, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_ZPLANE_POSITION, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_ZPLANE_POSITION, 2));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_ZPLANE_POSITION, 3));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_ZPLANE_POSITION, 4));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_ZPLANE_POSITION, 5));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_ZPLANE_POSITION, 6));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_ZPLANE_POSITION, 7));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_ZPLANE_POSITION, 8));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_ZPLANE_POSITION, 9));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_ZPLANE_POSITION, 10));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_ZPLANE_POSITION, 11));
    errChk(SetCtrlAttribute (hPanel, CLISTP_TEXTMSG_3, ATTR_ZPLANE_POSITION, 12));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_ZPLANE_POSITION, 13));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_ZPLANE_POSITION, 14));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_ZPLANE_POSITION, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_ZPLANE_POSITION, 16));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_ZPLANE_POSITION, 17));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_ZPLANE_POSITION, 18));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_ZPLANE_POSITION, 19));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION, ATTR_ZPLANE_POSITION, 20));
    errChk(SetCtrlAttribute (hPanel, CLISTP_DECORATION_12, ATTR_ZPLANE_POSITION, 21));

    // Set up TAB order if necessary
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_RING, ATTR_CTRL_TAB_POSITION, 0));
    errChk(SetCtrlAttribute (hPanel, CLISTP_HOST_INDEX, ATTR_CTRL_TAB_POSITION, 1));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_FILE, ATTR_CTRL_TAB_POSITION, 2));
    errChk(SetCtrlAttribute (hPanel, CLISTP_SEND_LIST, ATTR_CTRL_TAB_POSITION, 3));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_COMMANDS, ATTR_CTRL_TAB_POSITION, 4));
    errChk(SetCtrlAttribute (hPanel, CLISTP_COMMAND_INDEX, ATTR_CTRL_TAB_POSITION, 5));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP, ATTR_CTRL_TAB_POSITION, 6));
    errChk(SetCtrlAttribute (hPanel, CLISTP_CMDREP_COUNT, ATTR_CTRL_TAB_POSITION, 7));
    errChk(SetCtrlAttribute (hPanel, CLISTP_LIST_REP_COUNTER, ATTR_CTRL_TAB_POSITION, 8));
    errChk(SetCtrlAttribute (hPanel, CLISTP_NUM_OF_LIST_REP, ATTR_CTRL_TAB_POSITION, 9));
    errChk(SetCtrlAttribute (hPanel, CLISTP_EDIT_CLIST, ATTR_CTRL_TAB_POSITION, 10));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CMDREP, ATTR_CTRL_TAB_POSITION, 11));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_REP_LIST_NUM, ATTR_CTRL_TAB_POSITION, 12));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STOPPED, ATTR_CTRL_TAB_POSITION, 13));
    errChk(SetCtrlAttribute (hPanel, CLISTP_BUSY, ATTR_CTRL_TAB_POSITION, 14));
    errChk(SetCtrlAttribute (hPanel, CLISTP_STATUS_BOX, ATTR_CTRL_TAB_POSITION, 15));
    errChk(SetCtrlAttribute (hPanel, CLISTP_IF_ERROR, ATTR_CTRL_TAB_POSITION, 16));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESUME_CTRL_THREAD, ATTR_CTRL_TAB_POSITION, 17));
    errChk(SetCtrlAttribute (hPanel, CLISTP_RESET_CTRL_THREAD, ATTR_CTRL_TAB_POSITION, 18));

    // Finalize panel colors, positioning, and sizing
    errChk(SetPanelAttribute (hPanel, ATTR_CONFORM_TO_SYSTEM, 0));
    errChk(SetPanelAttribute (hPanel, ATTR_SCALE_CONTENTS_ON_RESIZE, 1));
    errChk(GetSystemAttribute (ATTR_RESOLUTION_ADJUSTMENT, &resAdjustment));
    if (resAdjustment == VAL_USE_PANEL_SETTING)
        resAdjustment = 0;
    if (resAdjustment)
        {
        errChk(GetMonitorFromPanel (hPanel, &monitorId));
        errChk(GetMonitorAttribute (monitorId, ATTR_HEIGHT, &screenHeight));
        errChk(GetMonitorAttribute (monitorId, ATTR_WIDTH, &screenWidth));
        SFv = (((float)screenHeight/1200)-1)*0.01*resAdjustment+1;
        errChk(SetPanelAttribute (hPanel, ATTR_HEIGHT, (int)(510*SFv)));
        SFh = (((float)screenWidth/1498)-1)*0.01*resAdjustment+1;
        errChk(SetPanelAttribute (hPanel, ATTR_WIDTH, (int)(326*SFh)));
        errChk(SetPanelAttribute (hPanel, ATTR_TOP, (int)(85*SFv)));
        errChk(SetPanelAttribute (hPanel, ATTR_LEFT, (int)(424*SFh)));
        }
    errChk(SetPanelAttribute (hPanel, ATTR_SCALE_CONTENTS_ON_RESIZE, 0));

    errChk(buildCmdListStatusMenu (hPanel));

    //We're done!
    return hPanel;
Error:
    if (bitmapId)
        DiscardBitmap (bitmapId);
    return error;
}

//----------------------------------------------------------------------------------------------------
// buildCmdListStatusMenu ():  Build UI object CSTAT_MENU; return handle or standard UI error code.
//----------------------------------------------------------------------------------------------------
int buildCmdListStatusMenu (int hParentPanel)
{
    int hMenubar;
    int error = 0;

    // Create the menubar
    errChk(hMenubar = NewMenuBar (hParentPanel));
    errChk(SetMenuBarAttribute (hMenubar, 0, ATTR_CONSTANT_NAME, "CSTAT_MENU"));

    // Build menu: CSTAT_MENU_CLEAR_STATUS_WINDOW
    errChk(CSTAT_MENU_CLEAR_STATUS_WINDOW = NewMenu (hMenubar, "ClearStatusWindow", -1));
    errChk(SetMenuBarAttribute (hMenubar, CSTAT_MENU_CLEAR_STATUS_WINDOW, ATTR_CONSTANT_NAME, "CLEAR_STATUS_WINDOW"));
//  errChk(SetMenuBarAttribute (hMenubar, CSTAT_MENU_CLEAR_STATUS_WINDOW, ATTR_DIMMED, 0));
    errChk(SetMenuBarAttribute (hMenubar, CSTAT_MENU_CLEAR_STATUS_WINDOW, ATTR_CALLBACK_FUNCTION_POINTER, commandStatusMenu));

    // Build menu: CSTAT_MENU_OPEN_STATUS_FILE
    errChk(CSTAT_MENU_OPEN_STATUS_FILE = NewMenu (hMenubar, "OpenStatusFile", -1));
    errChk(SetMenuBarAttribute (hMenubar, CSTAT_MENU_OPEN_STATUS_FILE, ATTR_CONSTANT_NAME, "OPEN_STATUS_FILE"));
//  errChk(SetMenuBarAttribute (hMenubar, CSTAT_MENU_OPEN_STATUS_FILE, ATTR_DIMMED, 0));
    errChk(SetMenuBarAttribute (hMenubar, CSTAT_MENU_OPEN_STATUS_FILE, ATTR_CALLBACK_FUNCTION_POINTER, commandStatusMenu));

    // Build menu: CSTAT_MENU_CMD_LIST_EDITOR
    errChk(CSTAT_MENU_CMD_LIST_EDITOR = NewMenu (hMenubar, "CmdListEditor", -1));
    errChk(SetMenuBarAttribute (hMenubar, CSTAT_MENU_CMD_LIST_EDITOR, ATTR_CONSTANT_NAME, "CMD_LIST_EDITOR"));
//  errChk(SetMenuBarAttribute (hMenubar, CSTAT_MENU_CMD_LIST_EDITOR, ATTR_DIMMED, 0));
    errChk(SetMenuBarAttribute (hMenubar, CSTAT_MENU_CMD_LIST_EDITOR, ATTR_CALLBACK_FUNCTION_POINTER, commandStatusMenu));

    // Build menu: CSTAT_MENU_CLOSE_WINDOW
    errChk(CSTAT_MENU_CLOSE_WINDOW = NewMenu (hMenubar, "Hide", -1));
    errChk(SetMenuBarAttribute (hMenubar, CSTAT_MENU_CLOSE_WINDOW, ATTR_CONSTANT_NAME, "CLOSE_WINDOW"));
//  errChk(SetMenuBarAttribute (hMenubar, CSTAT_MENU_CLOSE_WINDOW, ATTR_DIMMED, 0));
    errChk(SetMenuBarAttribute (hMenubar, CSTAT_MENU_CLOSE_WINDOW, ATTR_CALLBACK_FUNCTION_POINTER, commandStatusMenu));

    //We're done!
    return hMenubar;
Error:
    return error;
}
